@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of MIDI files
 
-our $VERSION = '0.1300';
+our $VERSION = '0.1400';
 
 use Moo;
 use strictures 2;
@@ -279,7 +279,7 @@ sub process {
                 ( my $num = $p ) =~ tr/a-j/0-9/;
 
                 # Convert MIDI numbers to named durations.
-                my $text = _dura_convert($num);
+                my $text = $self->dura_convert($num);
 
                 $analysis .= sprintf "\t%d\t%d\t%s (%s)\n",
                     $j, $dura_phrase->{$p}, $num, $text;
@@ -322,7 +322,7 @@ sub process {
                 ( my $num = $p ) =~ tr/a-j/0-9/;
 
                 # Convert MIDI numbers to named notes.
-                my $text = _note_convert($num);
+                my $text = $self->note_convert($num);
 
                 $analysis .= sprintf "\t%d\t%d\t%s (%s)\n",
                     $j, $note_phrase->{$p}, $num, $text;
@@ -387,7 +387,7 @@ sub populate {
                     );
 
                     # Convert MIDI numbers to named notes.
-                    my $note_text = _note_convert($choice);
+                    my $note_text = $self->note_convert($choice);
 
                     $playback .= "\t$n\t$channel\t$choice $note_text\n";
 
@@ -429,7 +429,7 @@ sub populate {
                 $n++;
 
                 # Convert MIDI numbers to named notes.
-                my $note_text = _note_convert($phrase);
+                my $note_text = $self->note_convert($phrase);
 
                 $playback .= "\t$n\t$channel\t$phrase $note_text\n";
 
@@ -473,14 +473,9 @@ sub write {
     $self->score->write_score( $self->out_file );
 }
 
-sub _random_patch {
-    my ($self) = @_;
-    return $self->patches->[ int rand @{ $self->patches } ];
-}
 
-# Convert MIDI numbers to named durations.
-sub _dura_convert {
-    my $string = shift;
+sub dura_convert {
+    my ($self, $string) = @_;
 
     my @text;
 
@@ -505,9 +500,9 @@ sub _dura_convert {
     return join ' ', @text;
 }
 
-# Convert MIDI numbers to named notes.
-sub _note_convert {
-    my $string = shift;
+
+sub note_convert {
+    my ($self, $string) = @_;
 
     my @text;
 
@@ -519,6 +514,11 @@ sub _note_convert {
     return join ' ', @text;
 }
 
+sub _random_patch {
+    my ($self) = @_;
+    return $self->patches->[ int rand @{ $self->patches } ];
+}
+
 sub _is_integer0 {
     croak 'Not greater than or equal to zero'
         unless defined $_[0] && $_[0] =~ /^\d+$/;
@@ -553,7 +553,7 @@ MIDI::Ngram - Find the top repeated note phrases of MIDI files
 
 =head1 VERSION
 
-version 0.1300
+version 0.1400
 
 =head1 SYNOPSIS
 
@@ -601,6 +601,10 @@ version 0.1300
   print Dumper $mng->dura_net;
   print Dumper $mng->note_net;
 
+  # Convert a MIDI number string to a duration or note name.
+  my $named = $mng->dura_convert('1920');
+  $named = $mng->note_convert('60 61');
+
 =head1 DESCRIPTION
 
 C<MIDI::Ngram> parses a given list of MIDI files, finds the top
@@ -763,6 +767,18 @@ Add notes to the MIDI score and return the playback notes.
 
 Write out the MIDI file.
 
+=head2 dura_convert
+
+  $durations = $mng->dura_convert($string);
+
+Convert MIDI numbers to named durations.
+
+=head2 note_convert
+
+  $notes = $mng->note_convert($string);
+
+Convert MIDI numbers to named notes.
+
 =head1 SEE ALSO
 
 L<Moo>
